summaryrefslogtreecommitdiff
path: root/content/handlers/html/box_textarea.h
diff options
context:
space:
mode:
Diffstat (limited to 'content/handlers/html/box_textarea.h')
-rw-r--r--content/handlers/html/box_textarea.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/content/handlers/html/box_textarea.h b/content/handlers/html/box_textarea.h
index 822fc8b10..219ef2301 100644
--- a/content/handlers/html/box_textarea.h
+++ b/content/handlers/html/box_textarea.h
@@ -45,8 +45,8 @@ bool box_textarea_create_textarea(struct html_content *html,
* \param html html content object
* \param box box with textarea widget
* \param key keypress
* \return true iff keypress handled
*/
-bool box_textarea_keypress(struct html_content *html, struct box *box, uint32_t key);
+nserror box_textarea_keypress(struct html_content *html, struct box *box, uint32_t key);
#endif
@@ -45,8 +45,8 @@ bool box_textarea_create_textarea(struct html_content *html,
* \param box box with textarea widget
* \param key keypress
- * \return true iff keypress handled
+ * \return NSERROR_OK iff keypress handled
*/